@@ -11,6 +11,8 @@ use std::path::{Path, PathBuf};
 use std::process::{Command, Stdio};
 use sysctl::{Ctl, Sysctl};
 use sysinfo_ffi::sysinfo;
+use aparato::traits::*;
+use aparato::PCIDevice;
 
 impl From<sqlite::Error> for ReadoutError {
     fn from(e: sqlite::Error) -> Self {
@@ -323,6 +325,10 @@ impl GeneralReadout for LinuxGeneralReadout {
         crate::shared::shell(format)
     }
 
+    fn gpus(&self) -> Result<Vec<PCIDevice>, ReadoutError> {
+        Ok(PCIDevice::fetch_gpus())
+    }
+
     fn cpu_model_name(&self) -> Result<String, ReadoutError> {
         Ok(crate::shared::cpu_model_name())
     }
